@@ -11,12 +11,14 @@ use 5.008;
 use strict;
 use warnings;
 
-package Net::IP::Identifier::Plugin::HostingSlnInt;     # _ENTITY_REGEX_ Hosting Solutions
+# _ENTITY_REGEX_ hosting.solutions.international
+
+package Net::IP::Identifier::Plugin::HostingSlnInt;
 
 use Role::Tiny::With;
 with qw( Net::IP::Identifier_Role );
 
-our $VERSION = '0.106'; # VERSION
+our $VERSION = '0.110'; # VERSION
 
 sub new {
     my ($class, %opts) = @_;
@@ -58,7 +60,7 @@ Net::IP::Identifier::Plugin::HostingSlnInt - identify Hosting Solutions Internat
 
 =head1 VERSION
 
-version 0.106
+version 0.110
 
 =head1 SYNOPSIS
 
