@@ -50,7 +50,7 @@ use Net::IP::Identifier::WhoisParser;
 use Moo;
 use namespace::clean;
 
-our $VERSION = '0.106'; # VERSION
+our $VERSION = '0.110'; # VERSION
 
 our @request_columns = (
     {request_str => 'TEXT NOT NULL PRIMARY KEY',},
@@ -112,7 +112,7 @@ has whois_table_name => (
     is => 'lazy',
     default => sub { 'whois_cache' },
 );
-has parse_failed => (       # error message when parsine WHOIS result fails
+has parse_failed => (       # error message when parsing WHOIS result fails
     is => 'rw',
 );
 has timeout => (            # seconds before command timeout
@@ -123,7 +123,7 @@ has stale_timeout   => (    # time until cached record is considered stale
     is => 'rw',
     default => sub { 60 * 60 * 24 * 30 },   # 30 days
 );
-has try_ripe => (           # sigh, jwhois might not do this for IPv6, do it by hand
+has _try_ripe => (          # sigh, jwhois might not do this for IPv6, do it by hand
     is => 'rw',
 );
 has force_cache_miss => (
@@ -391,7 +391,7 @@ sub ip_str_to_net {
         $error = $_;
     };
     if ($error) {
-        print STDERR "$myName: don't understand $req_str\n$error";
+        print "# Error converting $req_str to Net object:\n$error";
         return '';
     }
     return $net;
@@ -447,7 +447,7 @@ sub find_in_cache { # try to find $req_net in database
     my $matches = $self->sth_select_request->fetchall_arrayref;
     # might be no matches
     if (not @{$matches}) {
-        print "# Not Found in cache(", $req_net->print, ")\n" if ($self->verbose);
+        print "# Not Found in cache($req_net)\n" if ($self->verbose);
         return;
     }
     my $id = $matches->[0][$self->whois_id];    # get ID of WHOIS record
@@ -456,13 +456,13 @@ sub find_in_cache { # try to find $req_net in database
     $matches = $self->sth_select_whois_by_id->fetchall_arrayref;
     # might be no matches
     if (not @{$matches}) {
-        print "# ERROR: ", $req_net->print, " found but no cached WHOIS record with id=$id\n";
+        print "# ERROR: $req_net found but no cached WHOIS record with id=$id\n";
         return;
     }
 
     my $match = $matches->[0];  # should be only one
     if (not $match) {    # shouldn't happen
-        print "# ERROR: ", $req_net->print, " points to empty cache with id=$id\n";
+        print "# ERROR: $req_net points to empty cache with id=$id\n";
         return;
     }
 
@@ -475,7 +475,7 @@ sub find_in_cache { # try to find $req_net in database
         #    we just pass the value directly, so convert to hex:
         $rec->$key(Math::BigInt->new(sprintf("0x%x", $rec->$key)));
     }
-    print "# Found in cache(", $req_net->print, ")\n" if ($self->verbose);
+    print "# Found in cache($req_net)\n" if ($self->verbose);
 
     return $rec;
 }
@@ -487,7 +487,7 @@ sub cache_miss {   # run WHOIS and cache result
     if ($self->parse_failed and
         $req_net->version == 6) {
         print "# Parsing WHOIS result failed, try RIPE\n" if ($self->verbose);
-        $self->try_ripe(1);
+        $self->_try_ripe(1);
         $whois_rec = $self->fetch_whois_rec($req_net);
     }
     if ($self->parse_failed) {  # sigh, we did what we could
@@ -530,7 +530,7 @@ sub fetch_whois_rec {
     my ($self, $req_net) = @_;
 
     my @cmd = ('jwhois');
-    push @cmd, '-h', 'whois.ripe.net' if ($self->try_ripe);
+    push @cmd, '-h', 'whois.ripe.net' if ($self->_try_ripe);
     push @cmd, $req_net->print;
     print "# Cache miss: running ", join(' ', @cmd), "\n" if ($self->verbose);
     my $ii = 0;
@@ -538,7 +538,7 @@ sub fetch_whois_rec {
     for (my $ii = 0; $ii < 3; ) {
         my ($timeout_err, $err);
         try {
-            print "run ", join(' ', @cmd), "\n";
+# print "run ", join(' ', @cmd), "\n";
             IPC::Run::run(
                 \@cmd, # run jwhois
                 '>',
@@ -547,11 +547,11 @@ sub fetch_whois_rec {
                 \$err,
                 IPC::Run::timeout( $self->timeout ),
             ) or $timeout_err = $?;
-            print "done\n";
+# print "done\n";
         }
         catch {
             $timeout_err = "# Caught: $_";
-            print "catch error\n";
+# print "catch error\n";
         };
         print "# $err" if ($err);
 
@@ -699,7 +699,7 @@ Net::IP::Identifier::WhoisCache - Run whois, cache result in a database
 
 =head1 VERSION
 
-version 0.106
+version 0.110
 
 =head1 SYNOPSIS
 
@@ -707,15 +707,18 @@ version 0.106
 
 =head1 DESCRIPTION
 
-Net::IP::Identifier::WhoisCache runs WHOIS on an IP or netblock.  The result is cached in
-an SQLite database file.  If WHOIS is run later on any IP that falls within
-the same netblock, the cached information is returned (unless it's 'stale').
+Net::IP::Identifier::WhoisCache runs WHOIS on an IP or netblock.  The
+result is cached in an SQLite database file.  If the same IP or netblock is
+requested later, the cached information is returned (unless it's 'stale').
+Note that different requests must fetch WHOIS again even if the new request
+falls within a block covered by a previous request because the block may be
+subdivided such that the new request returns a different WHOIS result.
 
 =head2 Methods
 
 =over
 
-=item run()
+=item run
 
 This module is a modulino, meaning it may be used as a module or as a
 script.  The B<run> method is called when there is no caller and it is used
@@ -726,8 +729,8 @@ are provided on the command line, STDIN is used.
 
 Input (from a file, the command line, or STDIN) is scanned for things that
 look like IP (v4 or v6) addresses or blocks.  For each matching item, the
-B<Net::IP::Identifier::WhoisCache> object's B<get_whois> method (see below) is called
-on it, and the result is printed to STDOUT.
+B<Net::IP::Identifier::WhoisCache> object's B<get_whois> method (see below)
+is called on it, and the result is printed to STDOUT.
 
 Example:
 
@@ -750,10 +753,16 @@ and are also available as accessors:
 
 =over
 
+=item verbose
+
+Get/set a flag to produce diagnosics.
+
 =item db_filename
 
-SQLite database file name.  When run as a script, this can be changed
-on the command line with:
+SQLite database file name.  If it doesn't exist, it is created and
+initialized.
+
+When run as a script, this can be changed on the command line with:
 
     --db_filename new_name.sqlite
 
@@ -766,8 +775,7 @@ The database object (see perldoc DBI).
 =item request_table_name
 
 The table name for the request cache within the database.  Requests must map
-exactly to a previous request (netblocks must match).  Otherwise, a 'miss'
-could cause later nearby requests to suffer a false miss.
+exactly to a previous request (netblocks must match).
 
 =item whois_table_name
 
@@ -775,39 +783,58 @@ The table name for the WHOIS data cache within the database.
 
 Default: 'whois_cache'.
 
-=item sth_select_request
-
-A pre-built SQL handle for finding requests in the database.
-
-=item sth_insert_request
-
-SQL handle for inserting or updating requests into the database.  See
-B<sth_insert_whois> below for usage and note.
-
-=item sth_insert_whois
-
-SQL handle for inserting or updating WHOIS records to the database.  Used
-like this (given a Local::DBRecord object B<$rec>):
-
-    my @vals = map { $rec->$_ } $self->whois_sql_columns;
-    $self->sth_insert_whois->execute(@vals);
-
-NOTE: the SQL uses 'INSERT OR REPLACE', so all B<@vals> should be valid.
-
 =item timeout
 
-Timeout for running the whois command.
+Get/set the timeout (in seconds) for running the whois command.
 
 Default: 30 seconds.
 
 =item stale_timeout
 
-Number of seconds until a cached record is considered stale.
+Get/set the number of seconds until a cached record is considered stale.
 
 Default: 30 days worth of seconds.
 
+=item force_cache_miss
+
+Set/get a flag to force B<get_whois> to suffer a cache miss.
+
+When used from the command line, --miss (or -m) sets this flag.
+
 =back
 
+=item sth_select_request
+
+Returns an SQL handle for finding requests.
+
+=item sth_insert_request
+
+Returns an SQL handle for adding request to database.
+
+=item sth_select_whois_by_id
+
+Returns an SQL handle for finding WHOIS record by ID.
+
+=item sth_select_whois_by_range_str
+
+Returns an SQL handle for finding WHOIS record by range_str.
+
+=item sth_delete_ranges
+
+Returns an SQL handle for deleting IPs in the database.
+
+=item sth_delete_pattern
+
+Returns an SQL handle for deleting IPs based on pattern match.
+
+=item sth_insert_whois
+
+Returns an SQL handle for adding to the WHOIS database.
+
+=item sth_max_id
+
+Returns an SQL handle get the max ID value in WHOIS database.
+
 =item parse_fh ( $file_handle );
 
 Parse input from B<$file_handle>, looking for things that look like IP
@@ -830,6 +857,9 @@ Otherwise, runs WHOIS and update the cache.
 The B<Local::DBRecord> object contains the following methods for retrieving
 the database information
 
+Can die if B<$ip> is a netblock that cannot be represented by a CIDR (meaning
+it's boundaries are not on a binary power block).
+
 =over
 
 =item id
@@ -900,6 +930,19 @@ B<cache_miss>.
 
 Returns a Local::DBRecord object (see B<get_whois> above).
 
+=item fetch_whois_rec( $net )
+
+Runs 'jwhois' attempting to fetch WHOIS information about $net.  If no
+information can be retrieved (after several retries), throws and exception.
+Otherwise, the returned information is parsed and a Local::DBRecord is
+created and returned.
+
+=item parse_failed ( [ 'reason' ] )
+
+Set/get a reason why parsing of the WHOIS information failed.  Can be either
+that no netblock representing the original request was extracted, or because
+no specific entity could be determined for the netblock.
+
 =item cache_miss ( $req_net );
 
 Run WHOIS on B<$req_net> (a Net::IP::Identifier::Net object) and cache result.
@@ -907,11 +950,17 @@ Add a new WHOIS record, or update if there is an old (stale) one.
 
 Returns a Local::DBRecord object (see B<get_whois> above).
 
+=item request_sql_columns
+
 =item whois_sql_columns
 
-Return the column names used in the database.  In array context,
-return an array of the names.  In scalar context, returns the
-names joined by commas (suitable for use in SQL statements).
+Return the column names used in the request_cache or whois_cache tables.
+In array context, return an array of the names.  In scalar context, return
+the names joined by commas (suitable for use in SQL statements).
+
+=item max_id
+
+Returns the maximum ID field in the whois_cache table.
 
 =back
 
